##  Opening an Exported XML File in draw.io
The SAP LeanIX diagram can now be opened in
  1. Open draw.io in any of the browsers.
  2. Click on Start and open the editor, as you might need to decide how to save your diagram later.
  3. Drag and drop the XML file onto the canvas.


Your diagram is now available in [draw.io![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=http%3A%2F%2Fdiagrams.net%2F "http://diagrams.net/") editor for use.
![Gif that showing how to open a LeanIX diagram in draw.io](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274df67d7a44101489169269d16df257_LowRes.gif)
YesNo
Send
